import pystan
import numpy as np
import matplotlib.pyplot as plt

Data = [# ID  SA  SB
        ['A', 15, 15],
        ['A', 16, 16],
        ['A', 12, 19],
        ['A', 19, 12],
        ['B', 25, 25],
        ['B', 26, 26],
        ['B', 22, 29],
        ['B', 29, 22],
        ['C', 35, 35],
        ['C', 36, 36],
        ['C', 32, 39],
        ['C', 39, 32]
        ]

N = len(Data)
Y = []
X = []
for v in Data:
    Y.append(v[2])
    X.append(v[1])

DataStan = {'N': N, 'Y':Y, 'X': X}

sm = pystan.StanModel(file = 'SRegEx.stan')

fit = sm.sampling(data = DataStan, n_jobs = 1)
print(fit)

smpl_b1 = fit['b1']
n_smpls = len(smpl_b1)
b1_pos = 0
for v in smpl_b1:
    if v > 0.0:
        b1_pos += 1
plt.hist(smpl_b1)
plt.xlabel('b1')
plt.title('Prop(b1 > 0) = {0:.3f}'.format(b1_pos/n_smpls))
plt.show()

smpl_Yregs = fit['Yreg']

Yreg = []
for i in range(N):
    Yreg.append([])

for v in smpl_Yregs:
    pos = 0
    for u in v:
        Yreg[pos].append(u)
        pos += 1

meanYreg = [0] * N
for i in range(N):
    meanYreg[i] = np.median(Yreg[i])
minYreg = np.amin(meanYreg)
maxYreg = np.amax(meanYreg)
plt.plot([minYreg, maxYreg], [minYreg, maxYreg], 'b--', label = 'y = x')
plt.plot(meanYreg, Y, 'bo')
plt.xlabel('Yreg')
plt.ylabel('Y')
plt.legend(loc = 2)
plt.show()
